@@ -7,6 +7,7 @@ from . import (
     bases,
     buffer,
     cache,
+    checks,
     constants,
     context,
     exceptions,
@@ -14,6 +15,7 @@ from . import (
     highlight,
     interpreter,
     lexer,
+    mapping,
     nodes,
     objects,
     parser,
@@ -32,14 +34,15 @@ __all__ = (
     'bases',
     'buffer',
     'cache',
+    'checks',
     'constants',
     'context',
     'exceptions',
     'handlers',
     'highlight',
-    'immutables',
     'interpreter',
     'lexer',
+    'mapping',
     'nodes',
     'objects',
     'parser',
@@ -47,7 +50,6 @@ __all__ = (
     'pysbuiltins',
     'results',
     'runner',
-    'singletons',
     'symtab',
     'token',
     'utils',
